The **pytorch-image-classification** command-line tools can be used for building
image classification models with PyTorch using various model architectures.

The code is base on the PyTorch imagenet example code:

https://github.com/pytorch/examples/tree/master/imagenet

